@@ -76,6 +76,7 @@ from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
 from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_rule_type_details
+from neutron_lib.api.definitions import qos_rules_alias
 from neutron_lib.api.definitions import revisionifmatch
 from neutron_lib.api.definitions import router_availability_zone
 from neutron_lib.api.definitions import router_interface_fip
@@ -90,6 +91,7 @@ from neutron_lib.api.definitions import sorting
 from neutron_lib.api.definitions import standard_attr_segment
 from neutron_lib.api.definitions import subnet
 from neutron_lib.api.definitions import subnet_onboard
+from neutron_lib.api.definitions import subnet_segmentid_enforce
 from neutron_lib.api.definitions import subnet_segmentid_writable
 from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import trunk
@@ -168,6 +170,7 @@ _ALL_API_DEFINITIONS = {
     qos_default,
     qos_gateway_ip,
     qos_rule_type_details,
+    qos_rules_alias,
     revisionifmatch,
     router_availability_zone,
     router_interface_fip,
@@ -182,6 +185,7 @@ _ALL_API_DEFINITIONS = {
     standard_attr_segment,
     subnet,
     subnet_onboard,
+    subnet_segmentid_enforce,
     subnet_segmentid_writable,
     subnetpool,
     trunk,
