@@ -114,7 +114,9 @@ KNOWN_EXTENSIONS = (
     'project-id',
     'provider',
     'qos',
+    'qos-bw-limit-direction',
     'qos-gateway-ip',
+    'qos-rules-alias',
     'quotas',
     'rbac-policies',
     'router',
@@ -130,6 +132,7 @@ KNOWN_EXTENSIONS = (
     'standard-attr-timestamp',
     'subnet_allocation',
     'subnet_onboard',
+    'subnet-segmentid-enforce',
     'subnet-segmentid-writable',
     'tag',
     'trunk',
